om.jobs
=======

.. contents::

.. autodata:: omegaml.jobs

    Methods:

        - :py:meth:`omegaml.notebook.jobs.OmegaJobs.list`
        - :py:meth:`omegaml.notebook.jobs.OmegaJobs.get`
        - :py:meth:`omegaml.notebook.jobs.OmegaJobs.put`
        - :py:meth:`omegaml.notebook.jobs.OmegaJobs.drop`
        - :py:meth:`omegaml.notebook.jobs.OmegaJobs.exists`
        - :py:meth:`omegaml.notebook.jobs.OmegaJobs.create`
        - :py:meth:`omegaml.notebook.jobs.OmegaJobs.export`
        - :py:meth:`omegaml.notebook.jobs.OmegaJobs.schedule`
        - :py:meth:`omegaml.notebook.jobs.OmegaJobs.metadata`
        - :py:meth:`omegaml.notebook.jobs.OmegaJobs.help`

    Mixins:

        - :py:class:`omegaml.notebook.jobschedule.JobSchedule`
        - :py:class:`omegaml.runtimes.mixins.nbtasks.JobTasks`

    Backends:

        *None*


.. autoclass:: omegaml.notebook.jobs.OmegaJobs
    :members:


Backends
--------

*None*

Mixins
------

.. autoclass:: omegaml.notebook.jobschedule.JobSchedule
    :members:

.. autoclass:: omegaml.runtimes.mixins.nbtasks.JobTasks
    :members:
